==> fet_5.5.5.orig.tar.gz: fet-5.5.5/src/interface/addconstraintstudentsmaxhoursdailyform.h <==
/***************************************************************************
                          addconstraintstudentsmaxhoursdailyform.h  -  description
                             -------------------
    begin                : 19 July 2007
    copyright            : (C) 2007 by Lalescu Liviu
    email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef ADDCONSTRAINTSTUDENTSMAXHOURSDAILYFORM_H
#define ADDCONSTRAINTSTUDENTSMAXHOURSDAILYFORM_H

#include "addconstraintstudentsmaxhoursdailyform_template.h"
#include "timetable_defs.h"
#include "timetable.h"
#include "fet.h"
//#include "fetmainform.h"

#include <q3combobox.h>
#include <qmessagebox.h>
#include <q3groupbox.h>
#include <qspinbox.h>
#include <qcheckbox.h>
#include <qpushbutton.h>
#include <qlineedit.h>
#include <q3textedit.h>

class AddConstraintStudentsMaxHoursDailyForm : public AddConstraintStudentsMaxHoursDailyForm_template  {
public:
	AddConstraintStudentsMaxHoursDailyForm();
	~AddConstraintStudentsMaxHoursDailyForm();

	void constraintChanged();
	void addCurrentConstraint();
};

#endif

==> fet_5.11.0.orig.tar.gz: fet-5.11.0/src/interface/addconstraintstudentsmaxhoursdailyform.h <==
/***************************************************************************
                          addconstraintstudentsmaxhoursdailyform.h  -  description
                             -------------------
    begin                : 19 July 2007
    copyright            : (C) 2007 by Lalescu Liviu
    email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef ADDCONSTRAINTSTUDENTSMAXHOURSDAILYFORM_H
#define ADDCONSTRAINTSTUDENTSMAXHOURSDAILYFORM_H

#include "ui_addconstraintstudentsmaxhoursdailyform_template.h"
#include "timetable_defs.h"
#include "timetable.h"
#include "fet.h"
//#include "fetmainform.h"

#include <q3combobox.h>
#include <qmessagebox.h>
#include <q3groupbox.h>
#include <qspinbox.h>
#include <qcheckbox.h>
#include <qpushbutton.h>
#include <qlineedit.h>
#include <q3textedit.h>

class AddConstraintStudentsMaxHoursDailyForm : public QDialog, Ui::AddConstraintStudentsMaxHoursDailyForm_template  {
	Q_OBJECT
public:
	AddConstraintStudentsMaxHoursDailyForm();
	~AddConstraintStudentsMaxHoursDailyForm();

public slots:
	void constraintChanged();
	void addCurrentConstraint();
};

#endif
